|pypi| |actions| |codecov| |downloads| |maintainability| |black|

edc-appconfig
-------------

Last app in ``INSTALLED_APPS`` for ``clinicedc`` projects::

    # settings.py

    INSTALLED_APPS = [
        ...
        "edc_appconfig.apps.AppConfig"
        ]



.. |pypi| image:: https://img.shields.io/pypi/v/edc-appconfig.svg
    :target: https://pypi.python.org/pypi/edc-appconfig

.. |actions| image:: https://github.com/clinicedc/edc-appconfig/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-appconfig/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-appconfig/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-appconfig

.. |downloads| image:: https://pepy.tech/badge/edc-appconfig
   :target: https://pepy.tech/project/edc-appconfig

.. |maintainability| image:: https://api.codeclimate.com/v1/badges/434041d6c2f424ce5fd7/maintainability
   :target: https://codeclimate.com/github/clinicedc/edc-appconfig/maintainability
   :alt: Maintainability

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code Style
